function s_0 = RCSmetallic_sphere(diam, npoints, fstart, fstop)

%-------------------------------------------------------------
%-- Calculates the RCS of metallic sphere of a given diameter 
%-- as function of frequency. It actually produces s_0 = sqrt(RCS/4pi).
%--
%-- calculations assume far field and in backscatter. calculations are
%-- based on Mie solution. References include: 
%--     Radar Cross section Handbook, Editor: George T. Ruck, 
%--     Plenum Press, New York, 1970 
%--
%-- diam: is the diameter of the sphere in inches 
%-- npoints: number of frequency points to calculate RCS at
%-- fstart: start freq in GHz
%-- fstop: stop freq in GHz
%--
%-- written for matlab: Adib Nashashibi 1/29/2016
%--------------------------------------------------------------
 VEL = 2.9979E+8; %speed of light (m/s) 
 TH = 1.0e10; %threshold value
 
 RADIUS = diam/2.0; %get the radius
 RADIUS = RADIUS*2.54/100.0; %change to meters
 
 delta = (fstop - fstart)/(npoints-1);
 freq = 1:1:npoints;
 freq = delta * freq + fstart-delta;
 X = 2*pi * freq * 1.0e9* RADIUS/VEL; % this is basically ka (wavenumber x radius)
 
 B = ones(npoints,1); CC = B; 
 E = zeros(npoints, 1); phase = E; s_0 = B *1.0e-12;
 AMP = B;
 
 for ii = 1: npoints
   T=0 ; 
   Test = 0;
   while Test < TH 
        T=T+1;
        A(ii)=B(ii);
        B(ii)=CC(ii);
        CC(ii)=A(ii) + B(ii) *1i *(1.0-2.0*T)/X(ii);
        E(ii)=E(ii) + 1i*(T+0.5) / ( CC(ii)* (B(ii)+CC(ii)*1i*(-T/X(ii))) );
        Test=abs(real(CC(ii)));
   end 
   AMP(ii)=(abs(E(ii)).^2) * 4.0*pi* (RADIUS.^2)/X(ii).^2;
   AMP(ii) = sqrt(AMP(ii));
   phase(ii)=atan2(imag(E(ii)), real(E(ii))); % phase in radians
   s_0(ii)=abs( AMP(ii)* (cos(phase(ii)) +1i*sin(phase(ii))) / sqrt(4.*pi) ); 
   
end    

 
end
